# simple aws lambda example in terraform
# uses index.js file in the same directory

variable "aws_access_key" {
	type = string
	description = "cli user access key"
	default = "YOUR_AWS_ACCESS_KEY"
}

variable "aws_secret_key" {
	type = string
	description = "cli user secret key"
	default = "YOUR_AWS_SECRET_KEY"
}

variable "aws_region" {
	type = string
	description = "lambda deployment region"
	default = "ap-south-1"
}

data "archive_file" "lambda_zip" {
    type          = "zip"
    source_file   = "index.js"
    output_path   = "lambda_function.zip"
}

resource "aws_iam_role" "iam_for_lambda_tf" {
  name 				 = "iam_for_lambda_tf"
  description 		 = "role for lambda"
  /* jsonencode better than EOF. EOF breaks the new terraform code. */
  assume_role_policy = jsonencode({
	"Version": "2012-10-17",
	"Statement": [
		{
		  "Action": "sts:AssumeRole",
		  "Principal": {
			"Service": "lambda.amazonaws.com"
		  },
		  "Effect": "Allow",
		  "Sid": ""
		}
	]
  })
}

resource "aws_lambda_function" "test_lambda" {
	filename                   = "lambda_function.zip"
	function_name       = "test_lambda"
	role                            = "${aws_iam_role.iam_for_lambda_tf.arn}"
	handler                     = "index.handler"
	source_code_hash = "${data.archive_file.lambda_zip.output_base64sha256}"
	runtime          	= "nodejs14.x"
}
